pub struct HealthFailure {
pub url: String,
pub detail: String,
pub budget_secs: u64,
}Expand description
A health gate that never went green within its budget, as neutral data the provider maps to its own fault.
Fields
url: Stringdetail: Stringbudget_secs: u64Trait Implementations
Sourceimpl Clone for HealthFailure
impl Clone for HealthFailure
Sourcefn clone(&self) -> HealthFailure
fn clone(&self) -> HealthFailure
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for HealthFailure
impl RefUnwindSafe for HealthFailure
impl Send for HealthFailure
impl Sync for HealthFailure
impl Unpin for HealthFailure
impl UnsafeUnpin for HealthFailure
impl UnwindSafe for HealthFailure